==> android-mvp-0.0.10-sources.jar: com/melo/android/mvp/business/Presenter.java <==
package com.melo.android.mvp.business;

import android.util.Log;

import com.melo.android.mvp.ui.fragment.IView;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;

public abstract class Presenter<V extends IView> implements IPresenter<V> {

    private V original;
    private V proxy;

    private final Handler handler;

    public Presenter(V original) {
        this.original = original;
        this.handler = new Handler(original);

        Class iView = getIView();

        proxy = (V) Proxy.newProxyInstance(iView.getClassLoader(),
                new Class[] { iView },
                handler);
    }

    private Class getIView() {
        Class<?>[] interfaces = this.original.getClass().getInterfaces();

        for (Class clazz: interfaces) {
            if (IView.class.isAssignableFrom(clazz))
                return clazz;
        }

        throw new UnsupportedOperationException("Interce IView not found in fragment");
    }

    @Override
    public void setView(V view) {
        original = view;
    }

    @Override
    public V getView() {
        if (proxy != null) return proxy;

        Log.e(getClass().getName(), "there are some problems because is returning the original view");

        return original;
    }

    private class Handler implements InvocationHandler {
        private final V original;

        public Handler(V original) {
            this.original = original;
        }

        public Object invoke(Object proxy, Method method, Object[] args) throws IllegalAccessException, IllegalArgumentException, InvocationTargetException {
            //Log.d(getClass().getName(), "passing through proxy view");

            if (original != null) {
                try {
                    return method.invoke(original, args);
                } catch (InvocationTargetException | NullPointerException e) {
                    Log.e(getClass().getName(), "fail to call method through proxy " + e.getMessage());
                }
            }

            Log.w(getClass().getName(), "view is null so just ignore the call");

            return null;
        }
    }
}

==> android-mvp-0.0.11-sources.jar: com/melo/android/mvp/business/Presenter.java <==
package com.melo.android.mvp.business;

import android.util.Log;

import com.melo.android.mvp.ui.fragment.IView;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;

public abstract class Presenter<V extends IView> implements IPresenter<V> {

    private V original;
    private V proxy;

    private final Handler handler;

    public Presenter(V original) {
        this.original = original;
        this.handler = new Handler();

        Class iView = getIView();

        proxy = (V) Proxy.newProxyInstance(iView.getClassLoader(),
                new Class[] { iView },
                handler);
    }

    private Class getIView() {
        Class<?>[] interfaces = this.original.getClass().getInterfaces();

        for (Class clazz: interfaces) {
            if (IView.class.isAssignableFrom(clazz))
                return clazz;
        }

        throw new UnsupportedOperationException("Interce IView not found in fragment");
    }

    @Override
    public synchronized void setView(V view) {
        Log.w(getClass().getName(), "setting original view as " + view);
        original = view;
    }

    @Override
    public synchronized V getView() {
        if (proxy != null) return proxy;

        Log.e(getClass().getName(), "there are some problems because is returning the original view");

        return original;
    }

    private class Handler implements InvocationHandler {

        public Handler() {
        }

        public Object invoke(Object proxy, Method method, Object[] args) throws IllegalAccessException, IllegalArgumentException, InvocationTargetException {
            //Log.d(getClass().getName(), "passing through proxy view");

            if (original != null) {
                return method.invoke(original, args);
            }

            Log.w(getClass().getName(), "view is null so just ignore the call");

            return null;
        }
    }
}
